pro initGraph, OBSList, FRMList, FDBList, CRSList, SJIframe, PZTnoChangeValue, PixCCDxfuv1, PixCCDxfuvSJI, $
    SpecData, SJIdata, WINsize, PosClock, xmax=xmax, ymax=ymax
    
  ;y-direction
  ytop=5 ;top margin
  ybottom=6 ;bottom margin
  ydist=10 ;distance between plots in y-direction
  
  ;x-direction
  xleft=13 ;left margin
  xright=13 ;right margin
  xdist=2 ;distance between plots in x-direction
  
  ;SJI
  extraDist=10 ;for 5th graph, extra distance between 4th and 5th SJI plot
  minSizeSJI=300 ;minimum size of a single SJI (larger axis)
  maxSizeSJI=700 ;maximum size of a single SJI (larger axis)
  maxfacy=1.2 ;factor by which the overview SJI can be larger in y-direction
  maxfacx=2 ;factor by which the overview SJI can be larger in x-direction
  
  ;FUV
  facxDist=4;distance mutliplied between spectral plots (for text)
  
  
  
  ;structures for each spectral window
  specstruct = {SpectralData, $
    name:'', $
    name2:'', $
    sum_spat:1, $
    sum_spec:1, $
    Exp_Duration:0, $
    Exp_Type:0, $;TODO (value is in the structure, but ignored)
    CRSindex:0, $
    FDBindex:0, $
    SubRegionID:0, $
    type:'', $
    WINcoords:dblarr(4), $
    SIMcoords:intarr(6), $
    nrticks:0, $
    data:ptr_new(), $
    min_show:0d, $
    max_show:0d}
    
  ;structures for each SJI window
  sjistruct = {SJIData, $
    name:'', $
    name2:'', $
    sum_spatX:1, $
    sum_spatY:1, $
    Exp_Duration:0, $
    Exp_Type:0, $;TODO (value is in the structure, but ignored)
    CRSindex:0, $
    FDBindex:0, $
    type:'', $
    WINcoords:dblarr(4), $
    Boxcoords:intarr(6), $
    Showcoords:intarr(6), $
    PZTx:0d, $
    PZTy:0d, $
    data:ptr_new(), $
    min_show:0d, $
    max_show:0d}
    
    
  ; get min and max position of left lower corner
  ;i.e. run through whole experiment and get all PZT values
  minX = [0, 0]
  maxX = [0, 0]
  PZT = [0, 0]
  for nrOBSrepeats=0,OBSList.Repeat_Obs-1 do begin ; loop over OBS repeats
    for nrFRM=0,OBSList.NumEntries-1 do begin ;loop over whole OBS, different FRMs
      ; set position of lower left corner of origin, according to PZT
      if (*(OBSList).PZT_A_Abs)[nrFRM] ne PZTnoChangeValue || $
        (*(OBSList).PZT_B_Abs)[nrFRM] ne PZTnoChangeValue || $
        (*(OBSList).PZT_C_Abs)[nrFRM] ne PZTnoChangeValue then begin
        PZT = pzt2xy((*(OBSList).PZT_A_Abs)[nrFRM], (*(OBSList).PZT_B_Abs)[nrFRM], (*(OBSList).PZT_C_Abs)[nrFRM])
        PZT = round(PZT*6)
        addstep=0
      endif else begin
        if N_ELEMENTS(PZTStep) ne 0 then PZT = PZT-PZTStep ;reverse last addition of step, because we want to add the current stepsize
        addstep=1
      endelse
      PZTStep = pzt2xy((*(OBSList).PZT_A_Step)[nrFRM], (*(OBSList).PZT_B_Step)[nrFRM], (*(OBSList).PZT_C_Step)[nrFRM])
      PZTStep = round(PZTStep*6)
      if addstep then PZT = PZT+PZTStep
      
      ;get current FRM index
      currentFRM=-1
      for i=0,N_ELEMENTS(FRMList)-1 do begin
        if (*(OBSList).FRM_ID)[nrFRM] eq FRMList[i].ID then begin
          currentFRM = i
          break
        endif
      endfor
      if currentFRM eq -1 then begin
        print, 'Could not find corresponding FRM ', (*(OBSList).FRM_ID)[nrFRM]
        return
      endif
      ;print, 'current FRM index ', currentFRM, '; ID: ', FRMList[currentFRM].ID
      
      for nrFRMrepeats=0,(*(OBSList).Repeat_FRM)[nrFRM]-1 do begin ; loop over FRM repeats
        for nrFDB=0,FRMList[currentFRM].NumEntries-1 do begin ; loop over current FRM, different entries
          PZTOFF = pzt2xy((*(FRMList[currentFRM]).PZT_A_Rel)[nrFDB], (*(FRMList[currentFRM]).PZT_B_Rel)[nrFDB], (*(FRMList[currentFRM]).PZT_C_Rel)[nrFDB])
          PZTOFF = round(PZTOFF*6)
          PZTcurrent = PZT + PZTOFF
          for i=0,1 do begin
            if PZTcurrent[i] lt minX[i] then minX[i] = PZTcurrent[i]
            if PZTcurrent[i] gt maxX[i] then maxX[i] = PZTcurrent[i]
          endfor
        ;print, pZTcurrent, minX, maxX
        endfor ;nrFDB=0,FRMList[useFRM].NumEntries-1
        ;change the position of the origin
        PZT = PZT + PZTStep
      endfor ;nrFRMrepeats=0,(*(OBSList).Repeat_FRM)[nrFRM]-1
    endfor ;nrFRM=0,OBSList.NumEntries-1
  endfor ;nrOBSrepeats=0,OBSList.Repeat_Obs-1
  ;print, minX, maxX
  
  
  ;get number of spectral windows
  sji=0
  nuv=0
  fu1=0
  fu2=0
  for nrCRS = 0,N_ELEMENTS(CRSList)-1 do begin
    case CRSList[nrCRS].Type of
      'sji':sji = sji + CRSList[nrCRS].Subregions ;not used
      'nuv':nuv = nuv + CRSList[nrCRS].Subregions
      'fu1':fu1 = fu1 + CRSList[nrCRS].Subregions
      'fu2':fu2 = fu2 + CRSList[nrCRS].Subregions ; doesn't exist anymore
      else:print,'unknown window type'
    endcase
  endfor
  
  nWindows = nuv + fu1 + fu2
  SpecData = MAKE_ARRAY(nWindows, Value=specstruct) ; structure for spectral data
  
  ;populate spectral data structure
  n=0
  for typescan=0,1 do begin
    case typescan of
      0:seek='fu1'
      ;1:seek='fu2';doesn't exist anymore
      1:seek='nuv'
    endcase
    for nrCRS = 0,N_ELEMENTS(CRSList)-1 do begin
      if CRSList[nrCRS].Type eq seek then begin
        descr = CRSList[nrCRS].Description
        windescr = strsplit(descr,',',/extract, count=nWindescr)
        if nWindescr ne CRSList[nrCRS].Subregions then $
          print, 'number of subregions and number of elements in description do not fit (not critical), CRS-file: ', CRSList[nrCRS].ID
          
        for nrFDB=0,N_ELEMENTS(FDBList)-1 do begin
          if FDBList[nrFDB].CRSID eq CRSList[nrCRS].ID then begin
            inFDB=nrFDB
            break
          endif
        endfor
        
        for i=0,CRSList[nrCRS].Subregions-1 do begin
          if i gt nWindescr-1 then SpecData[n].name = '???' $
          else SpecData[n].name = windescr[i]
          SpecData[n].CRSindex = nrCRS
          SpecData[n].sum_spat = CRSList[nrCRS].Spatial
          SpecData[n].sum_spec = CRSList[nrCRS].Spectral
          if (SpecData[n].sum_spat gt 1) || (SpecData[n].sum_spec gt 1) then $
            SpecData[n].name2 = string(SpecData[n].sum_spec,format='(I1)') + 'x' + string(SpecData[n].sum_spat,format='(I1)')
          SpecData[n].FDBindex = inFDB
          SpecData[n].Exp_Duration = FDBList[inFDB].Exp_Duration
          SpecData[n].Exp_Type = FDBList[inFDB].Exp_Type
          SpecData[n].SubRegionID = (*(CRSList[nrCRS]).SubRegionID)[i]
          if typescan eq 0 then begin
            if (*(CRSList[nrCRS]).StartRow)[i] gt PixCCDxfuv1 then type = 'fu2' else type = 'fu1'
          endif else type = 'nuv'
          SpecData[n].type = type
          SpecData[n].SIMcoords[0] = (*(CRSList[nrCRS]).StartRow)[i]-1 ;in Ankurs tool it starts at 1
          SpecData[n].SIMcoords[1] = (*(CRSList[nrCRS]).NumRows)[i]
          SpecData[n].SIMcoords[2] = (*(CRSList[nrCRS]).StartCol)[i]-1
          SpecData[n].SIMcoords[3] = (*(CRSList[nrCRS]).NumCols)[i]
          SpecData[n].SIMcoords[4] = SpecData[n].SIMcoords[0] + (*(CRSList[nrCRS]).NumRows)[i] - 1
          SpecData[n].SIMcoords[5] = SpecData[n].SIMcoords[2] + (*(CRSList[nrCRS]).NumCols)[i] - 1
          SpecData[n].data = ptr_new(fltarr(SpecData[n].SIMcoords[1]/SpecData[n].sum_spec, SpecData[n].SIMcoords[3]/SpecData[n].sum_spat))
          n = n+1
        endfor
      endif ;else if CRSList[nrCRS].Type eq 'sji' then usesji=nrCRS
    endfor
  endfor
  
  
  
  ;get number of SJI windows
  sji=0
  sjiType=strarr(20)
  sjiFDB=intarr(20)
  sjiCRS=intarr(20)
  sjiFW=intarr(20)
  
  for nrFRM=0,N_ELEMENTS(FRMList)-1 do begin ;loop over all FRM
    for nrFDB=0,FRMList[nrFRM].NumEntries-1 do begin ; loop over current FRM, different entries
      if (*(FRMList[nrFRM]).SJI_FDB_ID)[nrFDB] ne '0' then begin ;there is a SJI in this entry, search corresponding FDB
        for currentFDB=0,N_ELEMENTS(FDBList)-1 do begin ;loop over all FDBs to find it
          if (*(FRMList[nrFRM]).SJI_FDB_ID)[nrFDB] eq FDBList[currentFDB].ID then begin ;found corresponding FDB, look for corresponding CRS
            for currentCRS=0,N_ELEMENTS(CRSList)-1 do begin ;loop over all CRS to find it
              if FDBList[currentFDB].CRSID eq CRSList[currentCRS].ID then begin ;found it, now check, if it is already in the list
                fw=(*(FRMList[nrFRM]).FW)[nrFDB]
                samefw = where(sjiFW eq fw, count)
                
                if count gt 0 then same = where(sjiCRS[samefw] eq currentCRS, count)
                if count eq 0 then begin ;we found a genuine new SJI
                  sjiFW[sji] = fw
                  sjiCRS[sji] = currentCRS
                  sjiFDB[sji] = currentFDB
                  case fw of
                    1: sjiType[sji] = 'Glass'
                    
                    31: begin
                      descr = strsplit(CRSList[currentCRS].Description,',',/extract)
                      if descr[0] eq 'FUV' then sjiType[sji] = 'FUV1' $
                      else sjiType[sji] = 'FUV0'
                    end
                    
                    61: begin
                      descr = strsplit(CRSList[currentCRS].Description,',',/extract)
                      if descr[0] eq 'NUV' then sjiType[sji] = 'NUV1' $
                      else sjiType[sji] = 'NUV0'
                    end
                    
                    91: begin
                      descr = strsplit(CRSList[currentCRS].Description,',',/extract)
                      if descr[0] eq 'FUV' then sjiType[sji] = 'FUV2' $
                      else sjiType[sji] = 'FUV0'
                    end
                    
                    121: begin
                      descr = strsplit(CRSList[currentCRS].Description,',',/extract)
                      if descr[0] eq 'NUV' then sjiType[sji] = 'NUV2' $
                      else sjiType[sji] = 'NUV0'
                    end
                    
                    151: sjiType[sji] = 'Broadband'
                    
                    else: sjiType[sji] = '???'
                  endcase
                  sji = sji+1
                endif
                break ;no need to look further in the CRS list
              endif
            endfor ;currentCRS
            break ;no need to look further in the FDB list
          endif
        endfor ;currentFDB
      endif
    endfor ;nrFDB
  endfor ;nrFRM
  
  SJIdata = MAKE_ARRAY(sji+1, Value=sjistruct) ; structure for SJI data
  
  
  ;populate SJI data structure
  n=1 ;first SJI is reserved for the overview SJI, will be populated further down
  minstartrow=PixCCDxfuvSJI
  maxendrow=0
  minstartcol=PixCCDxfuvSJI
  maxendcol=0
  minsize=PixCCDxfuvSJI
  maxsize=0
  for typescan=0,8 do begin
    case typescan of
      0: begin
        seek='FUV1'
        name='FUV1 1330 ' + ' [!3' + String("305B) + '!X]'
      end
      1: begin
        seek='FUV2'
        name='FUV2 1400 ' + ' [!3' + String("305B) + '!X]'
      end
      2: begin
        seek='FUV0'
        name='FUV0'
      end
      3: begin
        seek='NUV1'
        name='NUV1 2796 ' + ' [!3' + String("305B) + '!X]'
      end
      4: begin
        seek='NUV2'
        name='NUV2 2832 ' + ' [!3' + String("305B) + '!X]'
      end
      5: begin
        seek='NUV0'
        name='NUV0'
      end
      6: begin
        seek='Glass'
        name='Glass'
      end
      7: begin
        seek='Broadband'
        name='Broadband'
      end
      8: begin
        seek='???'
        name='???'
      end
    endcase
    for nrSJI = 0,sji-1 do begin
      if sjiType[nrSJI] eq seek then begin
        SJIData[n].name = name
        SJIData[n].type = sjiType[nrSJI];=seek
        SJIData[n].CRSindex = sjiCRS[nrSJI]
        SJIData[n].FDBindex = sjiFDB[nrSJI]
        SJIData[n].Exp_Duration = FDBList[sjiFDB[nrSJI]].Exp_Duration
        SJIData[n].Exp_Type = FDBList[sjiFDB[nrSJI]].Exp_Type
        SJIData[n].sum_spatX = CRSList[sjiCRS[nrSJI]].Spectral
        SJIData[n].sum_spatY = CRSList[sjiCRS[nrSJI]].Spatial
        if (SJIData[n].sum_spatX gt 1) || (SJIData[n].sum_spatY gt 1) then $
          SJIData[n].name2 = string(SJIData[n].sum_spatX,format='(I1)') + 'x' + string(SJIData[n].sum_spatY,format='(I1)')
        if (*(CRSList[sjiCRS[nrSJI]]).StartRow)[0] gt PixCCDxfuvSJI then $
          startrow = (*(CRSList[sjiCRS[nrSJI]]).StartRow)[0] - PixCCDxfuvSJI $
        else $
          startrow = (*(CRSList[sjiCRS[nrSJI]]).StartRow)[0]
        SJIData[n].Boxcoords[0] = startrow-1
        SJIData[n].Boxcoords[1] = (*(CRSList[sjiCRS[nrSJI]]).NumRows)[0]
        SJIData[n].Boxcoords[2] = (*(CRSList[sjiCRS[nrSJI]]).StartCol)[0]-1
        SJIData[n].Boxcoords[3] = (*(CRSList[sjiCRS[nrSJI]]).NumCols)[0]
        SJIData[n].Boxcoords[4] = startrow + (*(CRSList[sjiCRS[nrSJI]]).NumRows)[0] - 1
        SJIData[n].Boxcoords[5] = (*(CRSList[sjiCRS[nrSJI]]).StartCol)[0]-1 + (*(CRSList[sjiCRS[nrSJI]]).NumCols)[0] - 1
        SJIData[n].data = ptr_new(fltarr(SJIData[n].Boxcoords[1]/SJIData[n].sum_spatX, SJIData[n].Boxcoords[3]/SJIData[n].sum_spatY))
        if SJIData[n].Boxcoords[0] lt minstartrow then minstartrow=SJIData[n].Boxcoords[0]
        if SJIData[n].Boxcoords[4] gt maxendrow then maxendrow=SJIData[n].Boxcoords[4]
        if SJIData[n].Boxcoords[2] lt minstartcol then minstartcol=SJIData[n].Boxcoords[2]
        if SJIData[n].Boxcoords[5] gt maxendcol then maxendcol=SJIData[n].Boxcoords[5]
        if SJIData[n].Boxcoords[1] gt SJIData[n].Boxcoords[3] then ind=1 else ind=3
        if SJIData[n].Boxcoords[ind] gt maxsize then maxsize=SJIData[n].Boxcoords[ind]
        if SJIData[n].Boxcoords[ind] lt minsize then minsize=SJIData[n].Boxcoords[ind]
        n=n+1
      endif
    endfor
  endfor
  
  ;check if we have to adjust size according to set minimum and maximum size (minSizeSJI, maxSizeSJI)
  ;maximum has priority over minimum
  factorSJI=1d
  if maxsize gt maxSizeSJI then factorSJI = double(maxSizeSJI)/double(maxsize)
  
  
  ;overview SJI
  SJIData[0].name = 'SJI'
  SJIData[0].type = 'Overview'
  SJIData[0].Boxcoords[0] = minstartrow + minX[0] - SJIframe
  SJIData[0].Boxcoords[1] = maxendrow - minstartrow + 1 + maxX[0] - minX[0] + 2*SJIframe
  SJIData[0].Boxcoords[2] = minstartcol + minX[1] - SJIframe
  SJIData[0].Boxcoords[3] = maxendcol - minstartcol + 1 + maxX[1] - minX[1] + 2*SJIframe
  SJIData[0].Boxcoords[4] = SJIData[0].Boxcoords[0] + SJIData[0].Boxcoords[1] - 1
  SJIData[0].Boxcoords[5] = SJIData[0].Boxcoords[2] + SJIData[0].Boxcoords[3] - 1
  SJIData[0].data = ptr_new(fltarr(SJIData[0].Boxcoords[1], SJIData[0].Boxcoords[3]))
  factor2 = double(maxSizeSJI)*maxfacx/double(SJIData[0].Boxcoords[1])
  factor3 = double(maxSizeSJI)*maxfacy/double(SJIData[0].Boxcoords[3])
  factorSJI = min([factorSJI, factor2, factor3])
  if factorSJI ge 1d then begin
    if SJIData[0].Boxcoords[1] gt SJIData[0].Boxcoords[3] then ind=1 else ind=3
    if SJIData[0].Boxcoords[ind] lt minsize then minsize=SJIData[0].Boxcoords[ind] ;this should actually never be true
    if minsize lt minSizeSJI then factorSJI = double(minSizeSJI)/double(minsize)
  endif
  if sji gt 0 then begin
    SJIData[0].Showcoords[0] = SJIData[1].Boxcoords[0]
    SJIData[0].Showcoords[1] = SJIData[1].Boxcoords[1]
    SJIData[0].Showcoords[2] = SJIData[1].Boxcoords[2]
    SJIData[0].Showcoords[3] = SJIData[1].Boxcoords[3]
    SJIData[0].Showcoords[4] = SJIData[1].Boxcoords[4]
    SJIData[0].Showcoords[5] = SJIData[1].Boxcoords[5]
  endif
  
  
  
  ;get the size of SJI windows
  xRow=intarr(4) ;size of all graphs in one row in x-direction
  yRow=intarr(4) ;size of all graphs in one row in y-direction
  nWin=intarr(4) ;number of graphs in one row
  nWin[0]=sji+1
  for n=0,sji do begin
    xRow[0] = xRow[0] + SJIData[n].Boxcoords[1] * factorSJI
    if (SJIData[n].Boxcoords[3] * factorSJI) gt yRow[0] then yRow[0] = SJIData[n].Boxcoords[3] * factorSJI
  endfor
  
  
  ;get the size of the Spec windows
  ;rowSpec=intarr(nWindows)
  row=1
  for n=0,nWindows-1 do begin
    xRow[row] = xRow[row] + SpecData[n].SIMcoords[1]
    
    ;check if we need to have a second or third row for the spectras
    if (xRow[row] gt xmax) && (xRow[row] gt xRow[0]) && (row lt 3) then begin
      xRow[row] = xRow[row] - SpecData[n].SIMcoords[1]
      row = row + 1
      xRow[row] = xRow[row] + SpecData[n].SIMcoords[1]
    endif
    if SpecData[n].SIMcoords[3] gt yRow[row] then yRow[row] = SpecData[n].SIMcoords[3]
    nWin[row] = nWin[row] + 1
  endfor
  ;print,'nWin',nWin
  
  
  
  ;calculate size of the window
  if(!p.charsize ne 0) then pcharsize=!p.charsize else pcharsize=1.0
  
  ;y-direction
  nychar=ytop+ybottom+row*ydist ;sizes of margins in y-direction in units of char-size
  yannot=nychar*!d.y_ch_size*pcharsize ;total size in pixels of margins in y-direction
  ysize=total(yRow)+yannot ;total size in pixels of window in y-direction
  
  ;x-direction
  xannotS=intarr(4)
  xsizeS=intarr(4)
  
  ;SJI
  nxcharSJI=xleft+xright+sji*xdist+extraDist*xdist ;total size of margins in x-direction for SJI in units of char-size
  xannotS[0]=nxcharSJI*!d.x_ch_size*pcharsize ;total size in pixels of margins in x-direction for SJI
  xsizeS[0]=xRow[0]+xannotS[0] ;total size in pixels of SJI graphs in x-direction
  
  ;Spectra
  for i=1,3 do begin
    if nWin[i] gt 0 then nxcharSpec=xleft+xright+facxDist*(nWin[i]-1)*xdist else nxcharSpec=0
    xannotS[i]=nxcharSpec*!d.x_ch_size*pcharsize ;total size in pixels of margins in x-direction for spectral graphs in one row
    xsizeS[i]=xRow[i]+xannotS[i] ;total size in pixels of spectral graphs in x-direction in one row
  endfor
  
  xsize = max(xsizeS,maxin)
  
  fact=1.0
  ;decrease size if necessary
  if(n_elements(xmax) ne 0) then begin
    if(xsize gt xmax) then begin
      for i=0,3 do begin
        newx = fact*xRow[i]+xannotS[i]
        if newx gt xmax then fact=double(xmax-xannotS[i])/double(xRow[i])
      endfor
      ysize=fact*total(yRow)+yannot
      xsize=max(fact*xRow+xannotS)
    endif
  endif
  if(n_elements(ymax) ne 0) then begin
    if ysize gt ymax then begin
      facty=double(ymax-yannot)/double(fact*total(yRow))
      fact=fact*facty
      ysize=fact*total(yRow)+yannot
      xsize=max(fact*xRow+xannotS)
    endif
  endif
  
  WINsize=[xsize,ysize]
  
  ;caculate positons of each plot within window
  leftPos = xleft*!d.x_ch_size*pcharsize / xsize
  dxPos = xdist*!d.x_ch_size*pcharsize / xsize
  dyPos = ydist*!d.y_ch_size*pcharsize / ysize
  
  
  top = 1d - ytop*!d.y_ch_size*pcharsize / ysize
  bottom = top - fact * yRow[0] / ysize
  left = leftPos
  for j=0,nWin[0]-1 do begin
    top = bottom + fact * factorSJI * SJIData[j].Boxcoords[3] / ysize
    right = left + fact * factorSJI * SJIData[j].Boxcoords[1] / xsize
    SJIData[j].WINcoords = [left, bottom, right, top]
    if j lt nWin[0]-1 then left = right + dxPos
    if j eq 0 then begin
      left = left + extraDist*dxPos
      ;calculate also position of analog clock
      regionsize = fact * factorSJI * min([SJIData[j].Boxcoords[1], SJIData[j].Boxcoords[3]])
      PosClock=dblarr(4)
      PosClock[2] = regionsize/3./xsize
      PosClock[3] = regionsize/3./ysize
      PosClock[0] = right - PosClock[2]; * 9. / 24. / xsize
      PosClock[1] = top - PosClock[3]; - fact * factorSJI * SJIData[j].Boxcoords[3] /24. /ysize
    endif
  endfor
  
  n=0
  for i=1,3 do begin
    bottom = bottom - fact * yRow[i] / ysize - dyPos
    left = leftPos
    for j=0,nWin[i]-1 do begin
      top = bottom + fact * SpecData[n].SIMcoords[3] / ysize
      right = left + fact * SpecData[n].SIMcoords[1] / xsize
      SpecData[n].WINcoords = [left, bottom, right, top]
      SpecData[n].nrticks = fix(fact*double(SpecData[n].SIMcoords[1])/77./!p.charsize)+1
      if j lt nWin[i]-1 then left = right + facxDist*dxPos
      n=n+1
    endfor
  endfor
  
  
  
  
  
  
  
  
  
  if 0 then begin ;obsolete
  
  
    ;caculate positons of each plot within window
    leftPos = xleft*!d.x_ch_size*pcharsize / xsize
    dxPos = xdist*!d.x_ch_size*pcharsize / xsize
    dyPos = ydist*!d.y_ch_size*pcharsize / ysize
    lowSJI = ybottom*!d.y_ch_size*pcharsize / ysize
    lowFUV = lowSJI
    highFUV = lowFUV + fact*yFUV / ysize
    ;lowNUV = lowSJI
    ;highNUV = lowNUV + yNUV / ysize
    if (xFUV gt 0) || (xNUV gt 0) then begin
      lowSJI = highFUV + dyPos
    endif
    ;if xNUV gt 0 then begin
    ;  lowFUV = highNUV + dyPos
    ;  highFUV = lowFUV + yFUV / ysize
    ;  lowSJI = highFUV + dyPos
    ;endif
    highSJI0 = lowSJI + fact*ySJI0 / ysize
    highSJI5 = lowSJI + fact*ySJI / ysize
    
    
    
    locSJI=0
    plsizeSJI=0d
    locFUV=0
    plsizeFUV=0d
    ;locNUV=0
    ;plsizeNUV=0d
    for n = 0,nWindows-1 do begin
      ;if SpecData[n].type eq 'sji' then begin
      ;  left = leftPos+locSJI*dxPos+plsizeSJI
      ;  SpecData[n].WINcoords = [left, lowSJI, left+double(SpecData[n].SIMcoords[1])/xsize, highSJI]
      ;  locSJI=locSJI+1
      ;  plsizeSJI=plsizeSJI+double(SpecData[n].SIMcoords[1])/xsize
      ;  xSJI=double(SpecData[n].SIMcoords[1])/xsize
      ;endif else
      if (SpecData[n].type eq 'nuv') || (SpecData[n].type eq 'fu1') || (SpecData[n].type eq 'fu2') then begin
        left = leftPos+facxDist*locFUV*dxPos+plsizeFUV
        SpecData[n].WINcoords = [left, lowFUV, left+fact*double(SpecData[n].SIMcoords[1])/xsize, highFUV]
        locFUV=locFUV+1
        plsize=fact*double(SpecData[n].SIMcoords[1])
        plsizeFUV=plsizeFUV+plsize/xsize
        SpecData[n].nrticks = fix(plsize/77./!p.charsize)+1
      ;if SpecData[n].nrticks lt 1 then SpecData[n].nrticks=1
      ;print,'plotsize: ', n, plsize, SpecData[n].nrticks
      ;print,plsize/77.,!p.charsize
      endif; else if (SpecData[n].type eq 'fu1') || (SpecData[n].type eq 'fu2') then begin
    ;left = leftPos+locFUV*dxPos+plsizeFUV
    ;SpecData[n].WINcoords = [left, lowFUV, left+double(SpecData[n].SIMcoords[1])/xsize, highFUV]
    ;locFUV=locFUV+1
    ;plsizeFUV=plsizeFUV+double(SpecData[n].SIMcoords[1])/xsize
    ; endif; else if SpecData[n].type eq '' then begin
    ;left = leftPos+locSJI*dxPos+plsizeSJI
    ;SpecData[n].WINcoords = [left, lowSJI, left+xSJI, highSJI]
    ;locSJI=locSJI+1
    ;plsizeSJI=plsizeSJI+xSJI
    ;endif
    endfor
    
    
    
    for n = 0,4 do begin
      left = leftPos+locSJI*dxPos+plsizeSJI
      if n eq 4 then begin
        regionsize = fact*double(SJIData[n].Showcoords[1])/xsize
        left=left+extraDist*dxPos
        high=highSJI5
        ;calculate also position of analog clock
        PosClock=dblarr(4)
        PosClock[2] = regionsize/3.
        PosClock[3] = xsize/ysize*regionsize/3.
        PosClock[0] = left + regionsize*15./24.
        PosClock[1] = high - PosClock[3] - (high-lowSJI)/24.
      endif else begin
        regionsize=fact*double(SJIData[n].Boxcoords[1])/xsize
        high=highSJI0
      endelse
      SJIData[n].WINcoords = [left, lowSJI, left+regionsize, high]
      locSJI=locSJI+1
      plsizeSJI=plsizeSJI+regionsize
    ;xSJI=double(SJIData[n].Showcoords[1])/xsize
    ;print,'SJIwin: ', SJIData[n].WINcoords
    endfor
    
    
  endif ;obsolete
  
end
